# encoding=utf-8
"""
Auth: coco369
Email: 779598160@qq.com

CreateTime: 2021/07/29

Desc: fastspider核心代码, 控制器
"""
from threading import Thread


class Controller(Thread):

	def __init__(self):

		pass

	def get_requests(self, count):

		pass
